@@ -1,6 +1,6 @@
-#![feature(phase)]
 #![allow(bad_style)]
 #![allow(missing_copy_implementations)]
+#![feature(libc)]
 
 extern crate libc;
 
